@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def findSoftwareImages(vmanage):
     """
     Get software images
@@ -13,8 +10,8 @@ def findSoftwareImages(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/action/software"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/action/software"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def createImageURL(vmanage, payload):
@@ -30,8 +27,8 @@ def createImageURL(vmanage, payload):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/action/software"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, payload)
+    endpoint = f"dataservice/device/action/software"
+    response = vmanage.apiCall("POST", endpoint, payload)
     return response
 
 def getImageProps(vmanage, versionId):
@@ -47,8 +44,8 @@ def getImageProps(vmanage, versionId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/action/software/imageProperties/{versionId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/action/software/imageProperties/{versionId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def findImagesWithFilters(vmanage, imageType, vnfType):
@@ -65,8 +62,8 @@ def findImagesWithFilters(vmanage, imageType, vnfType):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/action/software/images?imageType={imageType}&vnfType={vnfType}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/action/software/images?imageType={imageType}&vnfType={vnfType}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def getPnfProperties(vmanage, pnfType):
@@ -82,8 +79,8 @@ def getPnfProperties(vmanage, pnfType):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/action/software/pnfproperties/{pnfType}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/action/software/pnfproperties/{pnfType}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def findVEdgeSoftwareVersion(vmanage):
@@ -98,8 +95,8 @@ def findVEdgeSoftwareVersion(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/action/software/vedge/version"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/action/software/vedge/version"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def findSoftwareVersion(vmanage):
@@ -114,8 +111,8 @@ def findSoftwareVersion(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/action/software/version"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/action/software/version"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def getVnfProperties(vmanage, versionId):
@@ -131,8 +128,8 @@ def getVnfProperties(vmanage, versionId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/action/software/vnfproperties/{versionId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/action/software/vnfproperties/{versionId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def findZtpSoftwareVersion(vmanage):
@@ -147,8 +144,8 @@ def findZtpSoftwareVersion(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/action/software/ztp/version"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/action/software/ztp/version"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def updateImageURL(vmanage, payload, versionId):
@@ -165,8 +162,8 @@ def updateImageURL(vmanage, payload, versionId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/action/software/{versionId}"
-    response = vmanage.client.apiCall(HttpMethods.PUT, endpoint, payload)
+    endpoint = f"dataservice/device/action/software/{versionId}"
+    response = vmanage.apiCall("PUT", endpoint, payload)
     return response
 
 def deleteImageURL(vmanage, versionId):
@@ -182,6 +179,6 @@ def deleteImageURL(vmanage, versionId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/action/software/{versionId}"
-    response = vmanage.client.apiCall(HttpMethods.DELETE, endpoint)
+    endpoint = f"dataservice/device/action/software/{versionId}"
+    response = vmanage.apiCall("DELETE", endpoint)
     return response
