@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def generateSecurityTemplateList(vmanage, mode):
     """
     Generate template list
@@ -14,8 +11,8 @@ def generateSecurityTemplateList(vmanage, mode):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/security?mode={mode}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/template/policy/security?mode={mode}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def createSecurityTemplate(vmanage, policytemplate):
@@ -31,8 +28,8 @@ def createSecurityTemplate(vmanage, policytemplate):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/security"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, policytemplate)
+    endpoint = f"dataservice/template/policy/security"
+    response = vmanage.apiCall("POST", endpoint, policytemplate)
     return response
 
 def getSecurityTemplate(vmanage, policyId):
@@ -48,8 +45,8 @@ def getSecurityTemplate(vmanage, policyId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/security/definition/{policyId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/template/policy/security/definition/{policyId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def getSecurityPolicyDeviceList(vmanage):
@@ -64,8 +61,8 @@ def getSecurityPolicyDeviceList(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/security/devices"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/template/policy/security/devices"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def getDeviceListById(vmanage, policyId):
@@ -81,8 +78,8 @@ def getDeviceListById(vmanage, policyId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/security/devices/{policyId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/template/policy/security/devices/{policyId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def editTemplateWithLenientLock(vmanage, policytemplate, policyId):
@@ -99,8 +96,8 @@ def editTemplateWithLenientLock(vmanage, policytemplate, policyId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/security/staging/{policyId}"
-    response = vmanage.client.apiCall(HttpMethods.PUT, endpoint, policytemplate)
+    endpoint = f"dataservice/template/policy/security/staging/{policyId}"
+    response = vmanage.apiCall("PUT", endpoint, policytemplate)
     return response
 
 def generateSecurityPolicySummary(vmanage):
@@ -115,8 +112,8 @@ def generateSecurityPolicySummary(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/security/summary"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/template/policy/security/summary"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def getSecurityTemplatesForDevice(vmanage, deviceModel):
@@ -132,8 +129,8 @@ def getSecurityTemplatesForDevice(vmanage, deviceModel):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/security/{deviceModel}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/template/policy/security/{deviceModel}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def editSecurityTemplate(vmanage, policytemplate, policyId):
@@ -150,8 +147,8 @@ def editSecurityTemplate(vmanage, policytemplate, policyId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/security/{policyId}"
-    response = vmanage.client.apiCall(HttpMethods.PUT, endpoint, policytemplate)
+    endpoint = f"dataservice/template/policy/security/{policyId}"
+    response = vmanage.apiCall("PUT", endpoint, policytemplate)
     return response
 
 def deleteSecurityTemplate(vmanage, policyId):
@@ -167,6 +164,6 @@ def deleteSecurityTemplate(vmanage, policyId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/security/{policyId}"
-    response = vmanage.client.apiCall(HttpMethods.DELETE, endpoint)
+    endpoint = f"dataservice/template/policy/security/{policyId}"
+    response = vmanage.apiCall("DELETE", endpoint)
     return response
