@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def getFlowCount(vmanage, deviceId):
     """
     Get App log flows count from device (Real Time)
@@ -14,8 +11,8 @@ def getFlowCount(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/app/log/flow-count?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/app/log/flow-count?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getFlows(vmanage, deviceId):
     """
@@ -30,6 +27,6 @@ def getFlows(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/app/log/flows?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/app/log/flows?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
