@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def getInterfaces(vmanage, deviceId):
     """
     Get device bridge interface list (Real Time)
@@ -14,8 +11,8 @@ def getInterfaces(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/bridge/interface?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/bridge/interface?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getInterfaceMac(vmanage, bridgeId, ifName, macAddr, deviceId):
     """
@@ -33,8 +30,8 @@ def getInterfaceMac(vmanage, bridgeId, ifName, macAddr, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/bridge/mac?bridgeId={bridgeId}&ifName={ifName}&macAddr={macAddr}&deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/bridge/mac?bridgeId={bridgeId}&ifName={ifName}&macAddr={macAddr}&deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getBridgeInterfaceTable(vmanage, deviceId):
     """
@@ -49,6 +46,6 @@ def getBridgeInterfaceTable(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/bridge/table?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/bridge/table?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
