@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def getBfdStats(vmanage, deviceId):
     """
     Get tunnel BFD statistics all devices
@@ -14,8 +11,8 @@ def getBfdStats(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/tunnel/bfd_statistics?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/tunnel/bfd_statistics?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getFecStats(vmanage, deviceId):
     """
@@ -30,8 +27,8 @@ def getFecStats(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/tunnel/fec_statistics?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/tunnel/fec_statistics?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getGreKeepalives(vmanage, deviceId):
     """
@@ -46,8 +43,8 @@ def getGreKeepalives(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/tunnel/gre-keepalives?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/tunnel/gre-keepalives?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getIpsecStats(vmanage, deviceId):
     """
@@ -62,8 +59,8 @@ def getIpsecStats(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/tunnel/ipsec_statistics?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/tunnel/ipsec_statistics?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getPacketDuplicateStats(vmanage, deviceId):
     """
@@ -78,8 +75,8 @@ def getPacketDuplicateStats(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/tunnel/packet-duplicate?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/tunnel/packet-duplicate?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getStats(vmanage, deviceId):
     """
@@ -94,6 +91,6 @@ def getStats(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/tunnel/statistics?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/tunnel/statistics?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
