@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def createUcseStats(vmanage, remote_tloc_address, remote_tloc_color, local_tloc_color, deviceId):
     """
     Get  UCSE stats entry from device
@@ -17,6 +14,6 @@ def createUcseStats(vmanage, remote_tloc_address, remote_tloc_color, local_tloc_
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/ucse/stats?remote-tloc-address={remote_tloc_address}&remote-tloc-color={remote_tloc_color}&local-tloc-color={local_tloc_color}&deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/ucse/stats?remote-tloc-address={remote_tloc_address}&remote-tloc-color={remote_tloc_color}&local-tloc-color={local_tloc_color}&deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
