@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def getCoLineSpecificStats(vmanage, deviceId):
     """
     Get VDSL service line bonding stats from device
@@ -14,8 +11,8 @@ def getCoLineSpecificStats(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/vdslService/coLineSpecificStats?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/vdslService/coLineSpecificStats?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getCoStats(vmanage, deviceId):
     """
@@ -30,8 +27,8 @@ def getCoStats(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/vdslService/coStats?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/vdslService/coStats?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getCpeLineSpecificStats(vmanage, deviceId):
     """
@@ -46,8 +43,8 @@ def getCpeLineSpecificStats(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/vdslService/cpeLineSpecificStats?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/vdslService/cpeLineSpecificStats?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getCpeStats(vmanage, deviceId):
     """
@@ -62,8 +59,8 @@ def getCpeStats(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/vdslService/cpeStats?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/vdslService/cpeStats?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getLineBondingStats(vmanage, deviceId):
     """
@@ -78,8 +75,8 @@ def getLineBondingStats(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/vdslService/lineBondingStats?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/vdslService/lineBondingStats?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getLineSpecificStats(vmanage, deviceId):
     """
@@ -94,8 +91,8 @@ def getLineSpecificStats(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/vdslService/lineSpecificStats?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/vdslService/lineSpecificStats?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getVdslInfo(vmanage, deviceId):
     """
@@ -110,6 +107,6 @@ def getVdslInfo(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/vdslService/vdslInfo?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/vdslService/vdslInfo?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
